pub struct GitRepository {
pub root_dir: PathBuf,
}Fields
root_dir: PathBufImplementations
Sourceimpl GitRepository
impl GitRepository
Sourcepub fn new<P: AsRef<Path>>(repository_path: P) -> Result<Self>
pub fn new<P: AsRef<Path>>(repository_path: P) -> Result<Self>
Create a new GitRepository instance for the given path Returns an error if the path is not a valid Git repository
Sourcepub fn commit_hash(&self) -> Result<String>
pub fn commit_hash(&self) -> Result<String>
Get the current commit hash (HEAD)
pub fn diff_files( &self, old_commit_hash: &str, ) -> Result<(Vec<PathBuf>, Vec<PathBuf>)>